
/*
		coordConvert.c

   Routines for going between various coordinate systems without
   having to know which corrections are being used.  These routines
   will automatically apply/remove corrections for rotation and
   fiber concentricity.

*/


#include <stdio.h>

#include "miscMath.h"
#include "motor.h"
#include "kaboom.h"
#include "plate.h"
#include "translate.h"
#include "buttons.h"
#include "nesslib.h"
#include "concen.h"
#include "coordConvert.h"



/************  GLOBALS  **********/

double RotationAngle = 0.0;

int Rotflag = 0;

/************  END GLOBALS  **********/


/************  Local Prototypes  **********/

static void    concenCoord( fibDB *fib, point *coordIn, point *coordOut );
static void  deConcenCoord( fibDB *fib, point *coordIn, point *coordOut );

static void    RotateCoord( point *coordIn, point *coordOut);
static void  deRotateCoord( point *coordIn, point *coordOut);

/************  End Local Prototypes  **********/
 

/* take a button location and turn it into a sky position in encoder units
   The translation functions called make the decisions as to whether or
   not to actually change the coordinate based on the mode flags */

void buttonToSky( fibDB *fib, point *coordOut )

{
   point tempCoord;

   /* remove concentricity correction if applicable */ 

   deConcenCoord( fib, &fib->CurGeometry->button, &tempCoord );

   /* remove rotation correction if applicable */

   deRotateCoord( &tempCoord, coordOut );
}



/* take a sky location and turn it into a button position in encoder units 
   The translation functions called make the decisions as to whether or
   not to actually change the coordinate based on the mode flags */

void skyToButton( fibDB *fib, point *coordIn, point *coordOut )

{
   point tempCoord;

   RotateCoord( coordIn, &tempCoord );

   /* add concentricity correction if applicable */ 

   concenCoord( fib, &tempCoord,  coordOut );

}



/****** local functions ******/


static void    concenCoord( fibDB *fib, point *coordIn, point *coordOut )

{
   point tmpVec;

   *coordOut = *coordIn;	/* might go untouched */

   if( EccenFlag == TRUE ){
      
      eccenCalcVec( fib, coordOut, &tmpVec );
      applyVec( coordOut, &tmpVec, NORMAL );
   }
}



static void  deConcenCoord( fibDB *fib, point *coordIn, point *coordOut )

{
   point tmpVec;

   *coordOut = *coordIn;	/* might go untouched */

   if( EccenFlag == TRUE ){
      
      eccenCalcVec( fib, coordOut, &tmpVec );
      applyVec( coordOut, &tmpVec, INVERT );
   }
}



static void    RotateCoord( point *coordIn, point *coordOut)

{

   *coordOut = *coordIn;	/* might go untouched */

   if( Rotflag == TRUE ){
      
      rotate( coordOut, RotationAngle );
   }
}



static void  deRotateCoord( point *coordIn, point *coordOut)

{
   *coordOut = *coordIn;	/* might go untouched */

   if( Rotflag == TRUE ){
      
      rotate( coordOut, -RotationAngle );
   }
}


